@@ -547,6 +547,25 @@ $DISCARD_PS = 1;
 $SHOW_SECTION_NUMBERS = 0;
 
 
+# -add_ref_name
+# -cut_ref_num
+# Usually cross reference text contains only the caption number as a
+# hyperlink to the corresponding LaTeX label. However, it could be
+# handy to see the name of the object referenced, if the reference text
+# would contain both the caption number and the caption name.
+# If $ADD_REF_NAME is 1, (option -add_ref_name), then the caption name
+# is shown additionally.
+# If $CUT_REF_NUM is 1, (option -cut_ref_num), then the caption number
+# is cut out, leaving the optional name only.
+# If $CUT_REF_NUM = 0 and $ADD_REF_NAME = 1, both caption number and
+# name are shown.
+# If $CUT_REF_NUM = 1 and $ADD_REF_NAME = 0, the cross reference text
+# is suppressed and a cross reference button shown instead.
+#
+$ADD_REF_NAME = 0;
+$CUT_REF_NUM  = 0;
+
+
 # -short_index
 # If this is set then  makeidx.perl  will construct codified names
 # for the text of index references.
@@ -734,19 +753,29 @@ $default_language = 'english';
 
 
 # The value of this variable determines how many words to use in each 
-# title that is added to the navigation panel (see below)
+# title that is added to the navigation panel, see below (-1 is no limit).
+# If $SHOW_SECTION_NUMBERS == 1, then one additional word counts
+# for the section number.
 # 
 $WORDS_IN_NAVIGATION_PANEL_TITLES = 4;
 
 
+# The value of this variable determines how many words to use in each 
+# Index entry (analogous to $WORDS_IN_NAVIGATION_PANEL_TITLES).
+# If not set, it equals to $WORDS_IN_NAVIGATION_PANEL_TITLES by default.
+# 
+#$WORDS_IN_INDEX = 4;
+
+
 # This number will determine the size of the equations, special characters,
 # and anything which will be converted into an inlined image
 # *except* "image generating environments" such as "figure", "table" 
 # or "minipage".
 # Effective values are those greater than 0.
 # Sensible values are between 0.1 - 4.
+# Adequate sizes of inlined images are achieved with the value near 1.6
 #
-$MATH_SCALE_FACTOR = 1;
+$MATH_SCALE_FACTOR = 1.6;
 
 
 # This number, when defined, determines extra scaling for displayed equations.
@@ -761,8 +790,9 @@ $MATH_SCALE_FACTOR = 1;
 # image generating environments such as "figure", "table" or "minipage".
 # Effective values are those greater than 0.
 # Sensible values are between 0.1 - 4.
+# Adequate image sizes are achieved with the value near 1.6
 #
-$FIGURE_SCALE_FACTOR = 1;
+$FIGURE_SCALE_FACTOR = 1.6;
 
 
 # This is yet another scaling factor which has a special use.
@@ -813,6 +843,7 @@ $PNMPAD = '/usr/bin/pnmpad';
 $PNMROTATE = '/usr/bin/pnmrotate';
 $PNMSCALE = '/usr/bin/pnmscale';
 $PNMCROP = '/usr/bin/pnmcrop';
+$PNMQUANT = '/usr/bin/pnmquant';
 
 $GIFTOPNM = '/usr/bin/giftopnm';
 $JPEGTOPNM = '/usr/bin/jpegtopnm';
@@ -869,6 +900,7 @@ sub english_titles {
     $idx_title = "Index";
     $ref_title = "References";
     $bib_title = "Bibliography";
+    $nom_title = "Nomenclature";
     $abs_title = "Abstract";
     $app_title = "Appendix";
     $pre_title = "Preface";
@@ -1049,18 +1081,16 @@ sub bot_navigation_panel {
 ### Meta Information #####################################################
 # 
 # This information will be inserted in the HEAD of the generated
-# HTML file. It can be used by automatic indexing scripts (eg
-# site-index.pl at http://www.ai.mit.edu/tools/site-index.html) 
-# You can change the description, keywords, etc. values.
+# HTML file.
+# You can set the description, keywords, etc. values.
 #
 sub meta_information {
     local($_) = @_;
     # Cannot have nested HTML tags...
     do { s/<[^>]*>//g;
-	"<META NAME=\"description\" CONTENT=\"$_\">\n" .
-	"<META NAME=\"keywords\" CONTENT=\"$FILE\">\n" .
-	"<META NAME=\"resource-type\" CONTENT=\"document\">\n" .
-	"<META NAME=\"distribution\" CONTENT=\"global\">\n"
+	# "<META NAME=\"description\" CONTENT=\"$_\">\n" .
+	# "<META NAME=\"keywords\" CONTENT=\"$FILE\">\n" .
+	""
     } if $_;
 }
 
